# Photonai Conformal
This project contains code to produce conformal predictions with photonai.

The conformal predictions are generated using the [mapie](https://mapie.readthedocs.io/en/latest/index.html) toolbox.